==> com.liferay.adaptive.media.document.library.thumbnails-5.0.21-sources.jar: com/liferay/adaptive/media/document/library/thumbnails/internal/upgrade/registry/AMDocumentLibraryThumbnailsUpgradeStepRegistrator.java <==
/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
 * details.
 */

package com.liferay.adaptive.media.document.library.thumbnails.internal.upgrade.registry;

import com.liferay.adaptive.media.document.library.thumbnails.internal.upgrade.v1_0_0.DocumentLibraryThumbnailsConfigurationUpgradeProcess;
import com.liferay.adaptive.media.document.library.thumbnails.internal.util.AMCompanyThumbnailConfigurationInitializer;
import com.liferay.portal.kernel.service.CompanyLocalService;
import com.liferay.portal.upgrade.registry.UpgradeStepRegistrator;

import org.osgi.service.component.annotations.Component;
import org.osgi.service.component.annotations.Reference;

/**
 * @author Roberto Díaz
 */
@Component(immediate = true, service = UpgradeStepRegistrator.class)
public class AMDocumentLibraryThumbnailsUpgradeStepRegistrator
	implements UpgradeStepRegistrator {

	@Override
	public void register(Registry registry) {
		registry.register(
			"0.0.0", "1.0.1",
			new DocumentLibraryThumbnailsConfigurationUpgradeProcess(
				_amCompanyThumbnailConfigurationInitializer,
				_companyLocalService));

		// See LPS-86356

		registry.register(
			"1.0.0", "1.0.1",
			new DocumentLibraryThumbnailsConfigurationUpgradeProcess(
				_amCompanyThumbnailConfigurationInitializer,
				_companyLocalService));
	}

	@Reference
	private AMCompanyThumbnailConfigurationInitializer
		_amCompanyThumbnailConfigurationInitializer;

	@Reference
	private CompanyLocalService _companyLocalService;

}

==> com.liferay.adaptive.media.document.library.thumbnails-5.0.31-sources.jar: com/liferay/adaptive/media/document/library/thumbnails/internal/upgrade/registry/AMDocumentLibraryThumbnailsUpgradeStepRegistrator.java <==
/**
 * SPDX-FileCopyrightText: (c) 2000 Liferay, Inc. https://liferay.com
 * SPDX-License-Identifier: LGPL-2.1-or-later OR LicenseRef-Liferay-DXP-EULA-2.0.0-2023-06
 */

package com.liferay.adaptive.media.document.library.thumbnails.internal.upgrade.registry;

import com.liferay.adaptive.media.document.library.thumbnails.internal.upgrade.v1_0_0.DocumentLibraryThumbnailsConfigurationUpgradeProcess;
import com.liferay.adaptive.media.document.library.thumbnails.internal.util.AMCompanyThumbnailConfigurationInitializer;
import com.liferay.portal.kernel.service.CompanyLocalService;
import com.liferay.portal.upgrade.registry.UpgradeStepRegistrator;

import org.osgi.service.component.annotations.Component;
import org.osgi.service.component.annotations.Reference;

/**
 * @author Roberto Díaz
 */
@Component(service = UpgradeStepRegistrator.class)
public class AMDocumentLibraryThumbnailsUpgradeStepRegistrator
	implements UpgradeStepRegistrator {

	@Override
	public void register(Registry registry) {
		registry.register(
			"0.0.0", "1.0.1",
			new DocumentLibraryThumbnailsConfigurationUpgradeProcess(
				_amCompanyThumbnailConfigurationInitializer,
				_companyLocalService));

		// See LPS-86356

		registry.register(
			"1.0.0", "1.0.1",
			new DocumentLibraryThumbnailsConfigurationUpgradeProcess(
				_amCompanyThumbnailConfigurationInitializer,
				_companyLocalService));
	}

	@Reference
	private AMCompanyThumbnailConfigurationInitializer
		_amCompanyThumbnailConfigurationInitializer;

	@Reference
	private CompanyLocalService _companyLocalService;

}
